@@ -1,5 +1,7 @@
 #-*- coding: utf-8 -*-
 
+from __future__ import unicode_literals
+
 from django import forms
 from django.utils import timezone
 
@@ -24,10 +26,10 @@ class ConfigForm(forms.Form):
         data = self.cleaned_data
         data['_updated_at'] = timezone.now()
 
-        for field_name, value in data.iteritems():
+        for field_name, value in data.items():
             count = Config.objects.filter(key=field_name).update(value=value)
 
             if not count:
                 Config.objects.create(key=field_name, value=value)
 
-        djconfig.load()
\ No newline at end of file
+        djconfig.load()
