@@ -22,7 +22,7 @@ class DjConfigLocMemMiddleware(object):
     def check_backend(self):
         backend = settings.CACHES[djconfig.BACKEND]
 
-        if not backend['BACKEND'].endswith(".LocMemCache"):
+        if not backend['BACKEND'].endswith((".LocMemCache", ".TestingCache")):
             raise ValueError("DjConfigLocMemMiddleware requires LocMemCache as cache")
 
     def reload(self):
@@ -32,4 +32,4 @@ class DjConfigLocMemMiddleware(object):
         data = dict(ConfigModel.objects.filter(key="_updated_at").values_list('key', 'value'))
 
         if data.get('_updated_at') != djconfig.config._updated_at:
-            djconfig.load()
\ No newline at end of file
+            djconfig.load()
